/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.server.http;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.server.coordinator.duty.DutyGroupStatus;

import java.util.List;

public class CoordinatorDutyStatus
{
  private final List<DutyGroupStatus> dutyGroups;

  @JsonCreator
  public CoordinatorDutyStatus(
      @JsonProperty("dutyGroups") List<DutyGroupStatus> dutyGroups
  )
  {
    this.dutyGroups = dutyGroups;
  }

  @JsonProperty
  public List<DutyGroupStatus> getDutyGroups()
  {
    return dutyGroups;
  }
}
